@@ -224,7 +224,7 @@ test -x $backup_prog  && backup_entry=$(entry \
     $"System Backup" \
     $"Make a backup of your system using “Luckybackup”.")
 
-equalizer_prog=/usr/bin/alsamixer
+equalizer_prog=/usr/share/applications/alsamixer-equalizer.desktop
 test -x $equalizer_prog  && equalizer_entry=$(entry \
     $ICONS/alsamixer-equalizer.png \
     "desktop-defaults-run -t alsamixer -D equalizer &" \
